from django.utils.safestring import mark_safe

from .form import Form


class MultiForm(Form):
    id_form = ""

    def __init__(self, id_form: str):
        super().__init__()
        self.id_form = id_form

    def _html_output(self,
                     normal_row,
                     error_row,
                     row_ender,
                     help_text_html,
                     errors_on_separate_row):
        output = super()._html_output(
            normal_row,
            error_row,
            row_ender,
            help_text_html,
            errors_on_separate_row)
        output2 = f"<input type='hidden' id='id_form' value='{self.id_form}'>"
        return mark_safe(output + output2)



from django.forms import models


class ModelForm(models.ModelForm):

    def as_div(self):
        """Return this form rendered as HTML <tr>s -- excluding the <table></table>."""
        return self._html_output(
            normal_row="""
            <div class="muses-field">
                %(label)s
                <div class="muses-control">
                %(field)s
                </div>
                %(errors)s
                %(help_text)s
            </div>
            """,
            error_row=""""<p class="muses-help muses-is-danger">%s</p>""",
            row_ender='</div>',
            help_text_html="""<p class="muses-help muses-is-success">%s</p>""",
            errors_on_separate_row=False,
        )
